@@ -4,7 +4,6 @@ describe 'vswitch::ovs' do
 
   let :default_params do {
     :package_ensure => 'present',
-    :dkms_ensure    => true,
   }
   end
 
@@ -108,9 +107,10 @@ describe 'vswitch::ovs' do
     let :params do default_params end
 
     let :facts do
-      {:osfamily => 'Redhat',
-       :ovs_version     => '1.4.2',
-      }
+      OSDefaults.get_facts({
+        :osfamily    => 'Redhat',
+        :ovs_version => '1.4.2',
+      })
     end
 
     let :platform_params do redhat_platform_params end
@@ -127,9 +127,10 @@ describe 'vswitch::ovs' do
     end
 
     let :facts do
-      {:osfamily => 'Redhat',
-       :ovs_version     => '1.4.2',
-      }
+      OSDefaults.get_facts({
+        :osfamily    => 'Redhat',
+        :ovs_version => '1.4.2',
+      })
     end
     let :platform_params do redhat_platform_params end
 
@@ -141,29 +142,11 @@ describe 'vswitch::ovs' do
     let :params do default_params end
 
     let :facts do
-      {:osfamily        => 'Debian',
-       :operatingsystem => 'Debian',
-       :ovs_version     => '1.4.2',
-      }
-    end
-    let :platform_params do debian_platform_params end
-
-    it_configures 'vswitch ovs'
-    it_configures 'install dkms'
-  end
-
-  context 'on Debian with parameters' do
-    let :params do {
-      :package_ensure => 'latest',
-      :dkms_ensure    => false,
-    }
-    end
-
-    let :facts do
-      {:osfamily        => 'Debian',
-       :operatingsystem => 'Debian',
-       :ovs_version     => '1.4.2',
-      }
+      OSDefaults.get_facts({
+        :operatingsystem => 'Debian',
+        :osfamily        => 'Debian',
+        :ovs_version     => '1.4.2',
+      })
     end
     let :platform_params do debian_platform_params end
 
@@ -171,33 +154,36 @@ describe 'vswitch::ovs' do
     it_configures 'do not install dkms'
   end
 
+  context 'on Debian with parameters' do
+    let :params do {
+      :package_ensure => 'latest',
+      :dkms_ensure    => true,
+    }
+    end
+
+    let :facts do
+      OSDefaults.get_facts({
+        :operatingsystem => 'Debian',
+        :osfamily        => 'Debian',
+        :ovs_version     => '1.4.2',
+      })
+    end
+    let :platform_params do debian_platform_params end
+
+    it_configures 'vswitch ovs'
+    it_configures 'install dkms'
+  end
+
   context 'on Ubuntu with default parameters' do
     let :params do default_params end
 
     let :facts do
-      {:osfamily        => 'Debian',
-       :operatingsystem => 'ubuntu',
-       :ovs_version     => '1.4.2',
-      }
-    end
-    let :platform_params do ubuntu_platform_params end
-
-    it_configures 'vswitch ovs'
-    it_configures 'install dkms'
-  end
-
-  context 'on Ubuntu with parameters' do
-    let :params do {
-      :package_ensure => 'latest',
-      :dkms_ensure    => false,
-    }
-    end
-
-    let :facts do
-      {:osfamily        => 'Debian',
-       :operatingsystem => 'ubuntu',
-       :ovs_version     => '1.4.2',
-      }
+      OSDefaults.get_facts({
+        :operatingsystem           => 'Ubuntu',
+        :operatingsystemmajrelease => '14',
+        :osfamily                  => 'Debian',
+        :ovs_version               => '1.4.2',
+      })
     end
     let :platform_params do ubuntu_platform_params end
 
@@ -205,14 +191,36 @@ describe 'vswitch::ovs' do
     it_configures 'do not install dkms'
   end
 
+  context 'on Ubuntu with parameters' do
+    let :params do {
+      :package_ensure => 'latest',
+      :dkms_ensure    => true,
+    }
+    end
+
+    let :facts do
+      OSDefaults.get_facts({
+        :operatingsystem           => 'Ubuntu',
+        :operatingsystemmajrelease => '14',
+        :osfamily                  => 'Debian',
+        :ovs_version               => '1.4.2',
+      })
+    end
+    let :platform_params do ubuntu_platform_params end
+
+    it_configures 'vswitch ovs'
+    it_configures 'install dkms'
+  end
+
   context 'on FreeBSD with default parameters' do
     let :params do default_params end
 
     let :facts do
-      {:osfamily        => 'FreeBSD',
-       :operatingsystem => 'FreeBSD',
-       :ovs_version     => '1.4.2',
-      }
+      OSDefaults.get_facts({
+        :osfamily        => 'FreeBSD',
+        :operatingsystem => 'FreeBSD',
+        :ovs_version     => '1.4.2',
+      })
     end
     let :platform_params do freebsd_platform_params end
 
@@ -237,10 +245,11 @@ describe 'vswitch::ovs' do
     end
 
     let :facts do
-      {:osfamily        => 'FreeBSD',
-       :operatingsystem => 'FreeBSD',
-       :ovs_version     => '1.4.2',
-      }
+      OSDefaults.get_facts({
+        :osfamily        => 'FreeBSD',
+        :operatingsystem => 'FreeBSD',
+        :ovs_version     => '1.4.2',
+      })
     end
     let :platform_params do freebsd_platform_params end
 
@@ -266,10 +275,11 @@ describe 'vswitch::ovs' do
     let :params do default_params end
 
     let :facts do
-      {:osfamily        => 'Solaris',
-       :operatingsystem => 'Solaris',
-       :ovs_version     => '2.3.1',
-      }
+      OSDefaults.get_facts({
+        :osfamily        => 'Solaris',
+        :operatingsystem => 'Solaris',
+        :ovs_version     => '2.3.1',
+      })
     end
     let :platform_params do solaris_platform_params end
 
@@ -294,10 +304,11 @@ describe 'vswitch::ovs' do
     end
 
     let :facts do
-      {:osfamily        => 'Solaris',
-       :operatingsystem => 'Solaris',
-       :ovs_version     => '2.3.1',
-      }
+      OSDefaults.get_facts({
+        :osfamily        => 'Solaris',
+        :operatingsystem => 'Solaris',
+        :ovs_version     => '2.3.1',
+      })
     end
     let :platform_params do solaris_platform_params end
 
